# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.octo_print_server import OctoPrintServer  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestOctoPrintServer(unittest.TestCase):
    """OctoPrintServer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OctoPrintServer
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.octo_print_server.OctoPrintServer()  # noqa: E501
        if include_optional :
            return OctoPrintServer(
                id = 56, 
                settings = None, 
                base_url = '', 
                base_path = '', 
                venv_path = '', 
                pip_path = '', 
                python_path = '', 
                octoprint_version = '', 
                pip_version = '', 
                python_version = '', 
                printnanny_plugin_version = '', 
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                api_key = '', 
                user = 56, 
                pi = 56
            )
        else :
            return OctoPrintServer(
                id = 56,
                settings = None,
                base_url = '',
                base_path = '',
                venv_path = '',
                pip_path = '',
                python_path = '',
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                user = 56,
                pi = 56,
        )

    def testOctoPrintServer(self):
        """Test OctoPrintServer"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
